aboutsummaryrefslogtreecommitdiff
path: root/libbuild2/cc/module.cxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2023-08-22 14:16:56 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2023-08-22 14:16:56 +0200
commit151b9cf30d11a014503b0a060a6bb7875c509adf (patch)
tree2fdf884b232bc8886a8e3f0f3027b21897b1be66 /libbuild2/cc/module.cxx
parent18e079b37794dc97b6c51045476bf43296b56dd3 (diff)
Consider *_inc{} target types as headers for rule match purposes
Diffstat (limited to 'libbuild2/cc/module.cxx')
-rw-r--r--libbuild2/cc/module.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/libbuild2/cc/module.cxx b/libbuild2/cc/module.cxx
index f33ddf4..3e756c4 100644
--- a/libbuild2/cc/module.cxx
+++ b/libbuild2/cc/module.cxx
@@ -994,14 +994,14 @@ namespace build2
install_path (rs, tt, dir_path ("include"));
};
// Note: module (x_mod) is in x_hdr.
//
- for (const target_type* const* ht (x_hdr); *ht != nullptr; ++ht)
+ for (const target_type* const* ht (x_hdrs); *ht != nullptr; ++ht)
insert_hdr (**ht);
// Also register the C header for C-derived languages.
//
- if (*x_hdr != &h::static_type)
+ if (*x_hdrs != &h::static_type)
insert_hdr (h::static_type);
rs.insert_target_type<pc> ();
@@ -994,14 +994,14 @@ namespace build2
install_path (rs, tt, dir_path ("include"));
};
- // Note: module (x_mod) is in x_hdr.
+ // Note: module (x_mod) is in x_hdrs.
//